Struct Disconnect
pub struct Disconnect<'a> {
pub reason_code: ReasonCode,
pub properties: &'a DisconnectProperties,
}Expand description
DISCONNECT packet signaling connection termination.
Fields
reason_code: ReasonCodeReason for disconnection.
properties: &'a DisconnectPropertiesDISCONNECT properties.
Implementations
impl<'a> Disconnect<'a>
impl<'a> Disconnect<'a>
pub const fn encoded_len(&self) -> usize
pub const fn encoded_len(&self) -> usize
Returns the encoded size of the variable header in bytes.
pub const fn encode(&self, w: &mut Writer<'_>) -> Result<(), EncodeError>
pub const fn encode(&self, w: &mut Writer<'_>) -> Result<(), EncodeError>
Encodes the DISCONNECT variable header into the writer.
Errors
Returns EncodeError::InsufficientSpace if the writer does not have
enough capacity.
pub const fn decode(r: &mut Reader<'a>) -> Result<Self, DecodeError>
pub const fn decode(r: &mut Reader<'a>) -> Result<Self, DecodeError>
Decodes a DISCONNECT packet from the reader.
Errors
Returns DecodeError if the data is malformed or contains an invalid
reason code or disallowed properties.